@@ -19,8 +19,8 @@ class ListMarshallerFactory(MarshallerFactoryABC):
                context: marshaller_context.MarshallerContext,
                type_: Type) -> Optional[marshaller_abc.MarshallerABC]:
         origin = typing_inspect.get_origin(type_)
-        if origin is list:
+        if origin in (list, set):
             item_type = typing_inspect.get_args(type_)[0]
             item_marshaller = DeferredMarshaller(item_type, context)
-            marshaller = IterableMarshaller[item_type](type_, item_marshaller)
+            marshaller = IterableMarshaller[item_type](type_, item_marshaller, origin)
             return marshaller
