@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Union, Set
 from unittest import TestCase
 
 from marshy import dump, load
@@ -13,6 +13,12 @@ class TestMarshallIterable(TestCase):
         loaded = load(List[int], dumped)
         assert values == loaded
 
+    def test_marshall_set(self):
+        values = set(range(10))
+        dumped = dump(values, Set[int])
+        loaded = load(Set[int], dumped)
+        assert values == loaded
+
     def test_dump(self):
         values = [True, None, 1, 'Mix']
         type_ = List[Union[bool, int, type(None), str]]
